@@ -23,7 +23,7 @@ class QueryAvatarRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'avatar', '2022-01-30', 'QueryAvatar')
-		self.set_method('GET')
+		self.set_method('POST')
 
 	def get_Code(self): # String
 		return self.get_query_params().get('Code')
